encode

Function encode 

pub fn encode(text: &str) -> Result<Vec<u8>, EncodeError>
Encodes text to Mac OS Roman. The first character with no byte gives an error.

This function does not replace a character that has no byte. A resource type code of four characters must give four bytes. If the encoder replaces a character, you find the wrong resource.